﻿/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'colorbutton', 'it', {
	auto: 'Automatico',
	bgColorTitle: 'Colore sfondo',
	colors: {
		'000': 'Nero',
		'800000': 'Marrone Castagna',
		'8B4513': 'Marrone Cuoio',
		'2F4F4F': 'Grigio Fumo di Londra',
		'008080': 'Acquamarina',
		'000080': 'Blu Oceano',
		'4B0082': 'Indigo',
		'696969': 'Grigio Scuro',
		B22222: 'Giallo Fiamma',
		A52A2A: 'Marrone',
		DAA520: 'Giallo Mimosa',
		'006400': 'Verde Scuro',
		'40E0D0': 'Turchese',
		'0000CD': 'Blue Scuro',
		'800080': 'Viola',
		'808080': 'Grigio',
		F00: 'Rosso',
		FF8C00: 'Arancio Scuro',
		FFD700: 'Oro',
		'008000': 'Verde',
		'0FF': 'Ciano',
		'00F': 'Blu',
		EE82EE: 'Violetto',
		A9A9A9: 'Grigio Scuro',
		FFA07A: 'Salmone',
		FFA500: 'Arancio',
		FFFF00: 'Giallo',
		'00FF00': 'Lime',
		AFEEEE: 'Turchese Chiaro',
		ADD8E6: 'Blu Chiaro',
		DDA0DD: 'Rosso Ciliegia',
		D3D3D3: 'Grigio Chiaro',
		FFF0F5: 'Lavanda Chiara',
		FAEBD7: 'Bianco Antico',
		FFFFE0: 'Giallo Chiaro',
		F0FFF0: 'Verde Mela',
		F0FFFF: 'Azzurro',
		F0F8FF: 'Celeste',
		E6E6FA: 'Lavanda',
		FFF: 'Bianco',
		'1ABC9C': 'Ciano intenso',
		'2ECC71': 'Smeraldo',
		'3498DB': 'Blu luminoso',
		'9B59B6': 'Ametista',
		'4E5F70': 'Blu grigiastro',
		'F1C40F': 'Giallo vivido',
		'16A085': 'Ciano scuro',
		'27AE60': 'Smeraldo scuro',
		'2980B9': 'Blu intenso',
		'8E44AD': 'Viola scuro',
		'2C3E50': 'Blu desaturato',
		'F39C12': 'Arancio',
		'E67E22': 'Carota',
		'E74C3C': 'Rosso pallido',
		'ECF0F1': 'Argento luminoso',
		'95A5A6': 'Ciano grigiastro chiaro',
		'DDD': 'Grigio chiaro',
		'D35400': 'Zucca',
		'C0392B': 'Rosso intenso',
		'BDC3C7': 'Argento',
		'7F8C8D': 'Ciano grigiastro',
		'999': 'Grigio scuro'
	},
	more: 'Altri colori...',
	panelTitle: 'Colori',
	textColorTitle: 'Colore testo'
} );
